@@ -9,6 +9,8 @@
 #[macro_use(quickcheck)]
 extern crate quickcheck_macros;
 
+#[cfg(feature = "server")]
+pub mod archive;
 #[cfg(feature = "server")]
 pub mod configuration;
 pub mod constants;
@@ -18,6 +20,7 @@ pub mod error;
 pub mod metrics;
 #[macro_use]
 mod macros;
+pub mod middleware;
 #[cfg(feature = "server")]
 pub mod routes;
 #[cfg(feature = "server")]
