@@ -1,9 +1,11 @@
 #!/usr/bin/env python3
 
-from pyauditor import AuditorClientBuilder, Record, Component, Meta
 import datetime
+
 from tzlocal import get_localzone
 
+from pyauditor import AuditorClientBuilder, Component, Meta, Record
+
 
 def main():
     local_tz = get_localzone()
